@@ -87,6 +87,9 @@ class ListAcumulator(FlowElement):
     def count(self):
         return len(self.list)
 
+    def __getitem__(self,i):
+        return self.list[i]
+
 class BreakPoint(FlowElement):
     def __init__(self,**debug_vars):
         self.list=[]
